nxp-pac

Crates

git

Versions

lpc55s16

Flavors

Mpu

Struct Mpu 

pub struct Mpu { /* private fields */ }
Memory Protection Unit.

Implementations

Source

impl Mpu

pub const unsafe fn from_ptr(ptr: *mut ()) -> Self

pub const fn as_ptr(&self) -> *mut ()

pub const fn type_(self) -> Reg<Type, R>

The MPU Type Register indicates how many regions the MPU support. Software can use it to determine if the processor implements an MPU.

pub const fn ctrl(self) -> Reg<Ctrl, RW>

MPU Control Register.

pub const fn rnr(self) -> Reg<Rnr, RW>

MPU Region Number Register.

pub const fn rbar(self) -> Reg<Rbar, RW>

MPU Region Base Address Register.

pub const fn rlar(self) -> Reg<Rlar, RW>

MPU Region Limit Address Register.

pub const fn rbar_a1(self) -> Reg<RbarA1, RW>

MPU Region Base Address Register.

pub const fn rlar_a1(self) -> Reg<RlarA1, RW>

MPU Region Limit Address Register.

pub const fn rbar_a2(self) -> Reg<RbarA2, RW>

MPU Region Base Address Register.

pub const fn rlar_a2(self) -> Reg<RlarA2, RW>

MPU Region Limit Address Register.

pub const fn rbar_a3(self) -> Reg<RbarA3, RW>

MPU Region Base Address Register.

pub const fn rlar_a3(self) -> Reg<RlarA3, RW>

MPU Region Limit Address Register.

pub const fn mair0(self) -> Reg<Mair0, RW>

MPU Memory Attribute Indirection Registers 0.

pub const fn mair1(self) -> Reg<Mair1, RW>

MPU Memory Attribute Indirection Registers 1.